* NOTE: Users must replace directory and file names for those listed here whenever using a "use," "joinby," "merge," or "save" command
use "D:\data\mid4.2\MIDB_42.dta", clear
* Changing negative values to missing data to avoid confusion when aggregating
for var dispnum3 - dispnum4 ccode - version : replace X=. if X<0
save "D:\data\mid4.2\mid participant.dta", replace
* Coding data for Side A
keep if sidea==1
ren * *a
ren ccodea statea
gen disno=dispnum4
replace disno=dispnum3 if disno==.
* Arbitrarily assigning start day as the first day of the month if start day is missing
* This is done in order to allow complete coding of duration and it matches the dyadic MID practice
replace stday=1 if stday==.
* Arbitrarily assigning end day as the last day of the month if end day is missing
* This is done in order to allow complete coding of duration and it matches the dyadic MID practice
replace endday=31 if endday==.
gen startdatea=styeara*100+stmona
replace startdatea=startdatea*100+stdaya
gen endatea=endyeara*100+endmona
replace endatea=endatea*100+enddaya
format endate %10.0f
save "D:\data\mid4.2\undirected dyadic mid42.dta", replace
* Coding data for side B
use "D:\data\mid4.2\mid participant.dta", clear
keep if sidea==0
ren * *b
ren ccodeb stateb
ren dispnum*b dispnum*
gen disno=dispnum4
replace disno=dispnum3 if disno==.
* Arbitrarily assigning start day as the first day of the month if start day is missing
* This is done in order to allow complete coding of duration and it matches the dyadic MID practice
replace stday=1 if stday==.
* Arbitrarily assigning end day as the last day of the month if end day is missing
* This is done in order to allow complete coding of duration and it matches the dyadic MID practice
replace endday=31 if endday==.
gen long startdateb=styearb*100+stmonb
replace startdateb=startdateb*100+stdayb
format start %10.0f
gen long endateb=endyearb*100+endmonb
replace endateb=endateb*100+enddayb
format endate %10.0f
* Joining the two sides into a single file
joinby disno using "D:\data\mid4.2\undirected dyadic mid42.dta", unmatched(none)
* Generating annual observations for MIDs that last cross two or more calendar years
egen startdate=rowmax(startdatea startdateb)
egen endate=rowmin(endatea endateb)
egen startyear=rowmax(styeara styearb)
egen endyear=rowmin(endyeara endyearb)
gen yeardiff=endyear-startyear+1
* Dropping MIDs in which the startyear is higher than the end year. These are dyads that cannot exist. Note that it is possible that an unexperienced user may actually used these MID dyads.
drop if yeardiff<=0
sort disno statea stateb startyear endyear
expand yeardiff if yeardiff>0
* Generating a yearly index for all MIDs (both single and multi year MIDs)
sort disno statea stateb startyear endyear
gen year=startyear if disno~=disno[_n-1] | statea~=statea[_n-1] | stateb~=stateb[_n-1]
replace year=year[_n-1]+1 if disno==disno[_n-1] & statea==statea[_n-1] & stateb==stateb[_n-1] & year==.
sort disno statea stateb year startyear endyear
compress
save "D:\data\mid4.2\undirected dyadic mid42.dta", replace
* Inserting outcome and Settlement Variables into the dyadic MID data
use "D:\data\mid4.2\MIDA_42.dta", clear
gen disno=dispnum4 if dispnum4~=.
replace disno=dispnum3 if dispnum4==.
keep settle outcome fatality fatalpre maxdur mindur hiact - numb ongo2010 disno
* Merging outcome, settlement, fatalities, high act and duration with the PSU dyadic MID data
merge 1:m disno using "D:\data\mid4.2\undirected dyadic mid42.dta"
drop _merge
order disno statea stateb year
save "D:\data\mid4.2\directed dyadic mid42.dta", replace
* Cleaning impossible dyads. Note, this is also a place where inexperienced users may retain dyads that are logically impossible to happen
* Same state on both sides
drop if statea==stateb
* Start date of statei after end date of statej
drop if statea==stateb
drop if styeara>endyearb
drop if styearb>endyeara
drop if styeara==endyearb & stmona>endmonb
drop if styeara==endyearb & stmonb>endmona
drop if styeara==endyearb & stmona==endmonb & stdaya>enddayb
drop if styeara==endyearb & stmona==endmonb & stdayb>enddaya
save "D:\data\mid4.2\undirected dyadic mid42.dta", replace
* Hostility Coding--Using Maoz Hostility Scale
gen severity=.
gen severitya=.
gen severityb=.
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=30 if X==1
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=1 if X==2
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=8 if X==3
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=49 if X==7
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=20  if X==8
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=8 if X==9
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=82 if X==10
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=55 if X==11
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=65 if X==12
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=96 if X==13
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=84 if X==14
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=81 if X==15
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=80 if X==16
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=75 if X==17
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=99 if X==18
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=92 if X==19
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=100 if X==20
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=100 if X==21
for var hiact hiacta hiactb \ var severity severitya severityb: replace Y=100 if X==23
replace severitya=0 if hiacta==0
replace severityb=0 if hiactb==0
replace severity=0 if hiact==0
label define severity 0 "None" 1 "Th. blockade" 8 "Th. Occ. Terr." 20 "alert" 29 "Th. Dec. War" 30 "Th. Use Force" 49 "Show Planes" 52 "Show Ships" 55 "Show Troops" 65 "border Viol" 75 "Clash" 80 "Raid" 81 "Seizure" 82 "Mobil" 84 "Occ. Terr" 96 "blockade" 99 "Dec. War" 100 "War", modify
label value severity* severity
compress
save "D:\data\mid4.2\undirected dyadic mid42.dta", replace
sort disno statea stateb year
* Assigning roles to participants to match dyadic MID roles
gen rolea=.
gen roleb=.
for var rolea roleb \ var sideaa sideab  \ var origa origb: replace X=1 if Y==1 & Z==1
for var rolea roleb \ var sideaa sideab  \ var origa origb: replace X=3 if Y==0 & Z==1
for var rolea roleb \ var sideaa sideab  \ var origa origb: replace X=2 if Y==1 & Z==0
for var rolea roleb \ var sideaa sideab  \ var origa origb: replace X=4 if Y==0 & Z==0
label define role 1 "Initiator" 2 "Joiner on Init. Side" 3 "Primary Target" 4 "Joiner on Target Side"
label value role* role
* Generating a code for last year in a dyadic MID
gen lastobs=1 if disno~=disno[_n+1] | statea~=statea[_n+1] | stateb~=stateb[_n+1]
replace lastobs=0 if lastobs==.
* Generating Outcomes
ren outcome outcom
gen outcome=2 if outcom>4 & outcom~=.
replace outcome=1 if rolea<3 & (outcom==1 | outcom==4) & outcome==.
replace outcome=3 if rolea<3 & (outcom==2 | outcom==3) & outcome==.
replace outcome=1 if rolea>=3 & (outcom==2 | outcom==3) & outcome==.
replace outcome=3 if rolea>=3 & (outcom==1 | outcom==4) & outcome==.
replace outcome=. if lastobs==0
* Generating Settlement codes
ren settle settlement
recode settlement (1=1) (2=2) (3/4=3), g(settle)
for var outcome settlement: replace X=. if lastobs==0
label define outcome 1 "Win" 2 "Draw" 3 "Lose"
label define settle 1 "Agreement" 2 "Imposed Settlmnt" 3 "Stalemate"
label value outcome outcome
label value settle settle
compress
save "D:\data\mid4.2\undirected dyadic mid42.dta", replace
* Generating a directed dyadic PSU MID datset from the MID participant file
ren *a *c
ren *b *a
ren *c *b
append using "D:\data\mid4.2\undirected dyadic mid42.dta"
compress
save "D:\data\mid4.2\directed dyadic mid42.dta", replace
* Coding War
gen war=1 if hostleva==5 & hostlevb==5
replace war=0 if war==.
sort disno statea stateb year
* Generating MID/war outbreaks
gen newmid=1 if disno~=disno[_n-1] | statea~=statea[_n-1] | stateb~=stateb[_n-1]
replace newmid=0 if disno==disno[_n-1] & statea==statea[_n-1] & stateb==stateb[_n-1]
gen newar=1 if war==1 & newmid==1
replace newar=0 if newar==.
sort disno statea stateb year
compress
save "D:\data\mid4.2\directed dyadic mid42.dta", replace

* Identifying dataset as PSU-generated
ren * psu*
ren psudisno disno
ren psustate* state*
ren psuyear year
save "D:\data\mid4.2\directed dyadic mid42.dta", replace
